Removed ``dates.YearLocator.replaced`` attribute
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

`.YearLocator` is now a subclass of `.RRuleLocator`, and the attribute
``YearLocator.replaced`` has been removed. For tick locations that
required modifying this, a custom rrule and `.RRuleLocator` can be used instead.